pub enum Overflow {
Fold,
Crop,
Ellipsis,
Ignore,
}Expand description
What to do with text that is wider than the space available.
Mirrors rich.console.OverflowMethod.
Variants
Fold
Break over-long words across lines. Upstream’s DEFAULT_OVERFLOW.
Crop
Cut the line off at the width.
Ellipsis
Cut the line off one cell early and mark it with ….
Ignore
Leave over-long lines intact, and do not wrap.