RenderStrOptions

Struct RenderStrOptions 

pub struct RenderStrOptions<'a> {
    pub style: StyleType,
    pub justify: Option<Justify>,
    pub overflow: Option<Overflow>,
    pub emoji: Option<bool>,
    pub markup: Option<bool>,
    pub highlight: Option<bool>,
    pub highlighter: Option<&'a dyn Highlighter>,
}
Keyword arguments of upstream’s Console.render_str, for Console::render_str_with. None takes the console’s default.

Fields

style: StyleType

Base style of the result (style=, default none).

justify: Option<Justify>

justify=; None leaves the text’s justify unset.

overflow: Option<Overflow>

overflow=; None leaves the text’s overflow unset.

emoji: Option<bool>

emoji=: replace emoji codes, or None for the console default.

markup: Option<bool>

markup=: parse console markup, or None for the console default.

highlight: Option<bool>

highlight=: highlight, or None for the console default.

highlighter: Option<&'a dyn Highlighter>

highlighter=: highlight with this instead of the console’s highlighters (registered ones plus ReprHighlighter).