Module control

Module control 

Terminal control codes.

Port of upstream rich/control.py. A Control is a renderable that emits a non-printable control sequence (cursor movement, screen clear, show/hide cursor, alt-screen toggle). It renders to a single control Segment, which the Console writes verbatim only when the output is a real terminal (control codes are meaningless when captured to a file).

Structs

Control
A renderable that inserts terminal control codes.

Enums

ControlType
Non-printable control codes which typically translate to ANSI sequences.