Screen

Struct Screen 

pub struct Screen { /* private fields */ }
A renderable that fills the screen and crops excess. Mirrors rich.screen.Screen.

Implementations

Source

impl Screen

pub fn new(renderable: Box<dyn Renderable>) -> Self

A screen filled with renderable.

pub fn empty() -> Self

An empty screen (blank fill).

pub fn style(self, style: Style) -> Self

Set a background style applied under the whole screen.