pub struct ProgressBar { /* private fields */ }Expand description
A progress bar. Mirrors rich.progress_bar.ProgressBar.
Implementations
Sourceimpl ProgressBar
impl ProgressBar
Sourcepub fn new(total: f64, completed: f64) -> Self
pub fn new(total: f64, completed: f64) -> Self
A bar of completed out of total, with upstream’s default bar.* styles.
Sourcepub fn indeterminate() -> Self
pub fn indeterminate() -> Self
A bar with no total, which always pulses (upstream total=None).
Sourcepub fn width(self, width: usize) -> Self
pub fn width(self, width: usize) -> Self
Fix the bar width (otherwise it fills the available width).
Sourcepub fn style(self, style: impl Into<StyleType>) -> Self
pub fn style(self, style: impl Into<StyleType>) -> Self
The background style (upstream style, default bar.back).
Sourcepub fn complete_style(self, style: impl Into<StyleType>) -> Self
pub fn complete_style(self, style: impl Into<StyleType>) -> Self
The completed-part style (upstream complete_style, default bar.complete).
Sourcepub fn finished_style(self, style: impl Into<StyleType>) -> Self
pub fn finished_style(self, style: impl Into<StyleType>) -> Self
The style once finished (upstream finished_style, default bar.finished).
Sourcepub fn pulse_style(self, style: impl Into<StyleType>) -> Self
pub fn pulse_style(self, style: impl Into<StyleType>) -> Self
The pulse style (upstream pulse_style, default bar.pulse).
Sourcepub fn pulse(self, pulse: bool) -> Self
pub fn pulse(self, pulse: bool) -> Self
Render the pulse animation instead of the completion (upstream pulse).
Sourcepub fn animation_time(self, time: f64) -> Self
pub fn animation_time(self, time: f64) -> Self
The time, in seconds, the pulse is drawn at (upstream animation_time).
Without it the pulse follows a monotonic clock.