Tree

Struct Tree 

pub struct Tree { /* private fields */ }
A node in a hierarchy. Mirrors rich.tree.Tree.

Implementations

Source

impl Tree

pub fn new(label: impl Into<String>) -> Self

A new tree/subtree with the given label.

pub fn add(&mut self, label: impl Into<String>) -> &mut Tree

Add a child with label, returning a mutable reference to it so further descendants can be attached. Mirrors Tree.add.